==> python-dateparser-1.0.0-2-any.pkg.tar.xz: usr/lib/python3.9/site-packages/dateparser/data/date_translation_data/km.py <==
info = {
    "name": "km",
    "date_order": "DMY",
    "january": [
        "មករា"
    ],
    "february": [
        "កុម្ភៈ"
    ],
    "march": [
        "មីនា"
    ],
    "april": [
        "មេសា"
    ],
    "may": [
        "ឧសភា"
    ],
    "june": [
        "មិថុនា"
    ],
    "july": [
        "កក្កដា"
    ],
    "august": [
        "សីហា"
    ],
    "september": [
        "កញ្ញា"
    ],
    "october": [
        "តុលា"
    ],
    "november": [
        "វិច្ឆិកា"
    ],
    "december": [
        "ធ្នូ"
    ],
    "monday": [
        "ច័ន្ទ"
    ],
    "tuesday": [
        "អង្គារ"
    ],
    "wednesday": [
        "ពុធ"
    ],
    "thursday": [
        "ព្រហស្បតិ៍"
    ],
    "friday": [
        "សុក្រ"
    ],
    "saturday": [
        "សៅរ៍"
    ],
    "sunday": [
        "អាទិត្យ"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "ឆ្នាំ"
    ],
    "month": [
        "ខែ"
    ],
    "week": [
        "សប្ដាហ៍"
    ],
    "day": [
        "ថ្ងៃ"
    ],
    "hour": [
        "ម៉ោង"
    ],
    "minute": [
        "នាទី"
    ],
    "second": [
        "វិនាទី"
    ],
    "relative-type": {
        "1 year ago": [
            "ឆ្នាំ​មុន"
        ],
        "0 year ago": [
            "ឆ្នាំ​នេះ"
        ],
        "in 1 year": [
            "ឆ្នាំ​ក្រោយ"
        ],
        "1 month ago": [
            "ខែ​មុន"
        ],
        "0 month ago": [
            "ខែ​នេះ"
        ],
        "in 1 month": [
            "ខែ​ក្រោយ"
        ],
        "1 week ago": [
            "សប្ដាហ៍​មុន"
        ],
        "0 week ago": [
            "សប្ដាហ៍​នេះ"
        ],
        "in 1 week": [
            "សប្ដាហ៍​ក្រោយ"
        ],
        "1 day ago": [
            "ម្សិលមិញ"
        ],
        "0 day ago": [
            "ថ្ងៃ​នេះ"
        ],
        "in 1 day": [
            "ថ្ងៃ​ស្អែក",
            "ថ្ងៃស្អែក"
        ],
        "0 hour ago": [
            "ម៉ោងនេះ"
        ],
        "0 minute ago": [
            "នាទីនេះ"
        ],
        "0 second ago": [
            "ឥឡូវ"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) ឆ្នាំទៀត"
        ],
        "\\1 year ago": [
            "(\\d+) ឆ្នាំ​មុន"
        ],
        "in \\1 month": [
            "(\\d+) ខែទៀត"
        ],
        "\\1 month ago": [
            "(\\d+) ខែមុន"
        ],
        "in \\1 week": [
            "(\\d+) សប្ដាហ៍ទៀត"
        ],
        "\\1 week ago": [
            "(\\d+) សប្ដាហ៍​មុន"
        ],
        "in \\1 day": [
            "(\\d+) ថ្ងៃទៀត"
        ],
        "\\1 day ago": [
            "(\\d+) ថ្ងៃ​មុន",
            "(\\d+) ថ្ងៃ​​មុន"
        ],
        "in \\1 hour": [
            "ក្នុង​រយៈ​ពេល (\\d+) ម៉ោង",
            "(\\d+) ម៉ោងទៀត"
        ],
        "\\1 hour ago": [
            "(\\d+) ម៉ោង​មុន"
        ],
        "in \\1 minute": [
            "(\\d+) នាទីទៀត"
        ],
        "\\1 minute ago": [
            "(\\d+) នាទី​មុន",
            "(\\d+) នាទី​​មុន"
        ],
        "in \\1 second": [
            "(\\d+) វិនាទីទៀត"
        ],
        "\\1 second ago": [
            "(\\d+) វិនាទី​មុន"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/km.py <==
info = {
    "name": "km",
    "date_order": "DMY",
    "january": [
        "មករា"
    ],
    "february": [
        "កុម្ភៈ"
    ],
    "march": [
        "មីនា"
    ],
    "april": [
        "មេសា"
    ],
    "may": [
        "ឧសភា"
    ],
    "june": [
        "មិថុនា"
    ],
    "july": [
        "កក្កដា"
    ],
    "august": [
        "សីហា"
    ],
    "september": [
        "កញ្ញា"
    ],
    "october": [
        "តុលា"
    ],
    "november": [
        "វិច្ឆិកា"
    ],
    "december": [
        "ធ្នូ"
    ],
    "monday": [
        "ច័ន្ទ"
    ],
    "tuesday": [
        "អង្គារ"
    ],
    "wednesday": [
        "ពុធ"
    ],
    "thursday": [
        "ព្រហស្បតិ៍"
    ],
    "friday": [
        "សុក្រ"
    ],
    "saturday": [
        "សៅរ៍"
    ],
    "sunday": [
        "អាទិត្យ"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "ឆ្នាំ"
    ],
    "month": [
        "ខែ"
    ],
    "week": [
        "សប្ដាហ៍"
    ],
    "day": [
        "ថ្ងៃ"
    ],
    "hour": [
        "ម៉ោង"
    ],
    "minute": [
        "នាទី"
    ],
    "second": [
        "វិនាទី"
    ],
    "relative-type": {
        "0 day ago": [
            "ថ្ងៃ​នេះ"
        ],
        "0 hour ago": [
            "ម៉ោងនេះ"
        ],
        "0 minute ago": [
            "នាទីនេះ"
        ],
        "0 month ago": [
            "ខែ​នេះ"
        ],
        "0 second ago": [
            "ឥឡូវ"
        ],
        "0 week ago": [
            "សប្ដាហ៍​នេះ"
        ],
        "0 year ago": [
            "ឆ្នាំ​នេះ"
        ],
        "1 day ago": [
            "ម្សិលមិញ"
        ],
        "1 month ago": [
            "ខែ​មុន"
        ],
        "1 week ago": [
            "សប្ដាហ៍​មុន"
        ],
        "1 year ago": [
            "ឆ្នាំ​មុន"
        ],
        "in 1 day": [
            "ថ្ងៃស្អែក",
            "ថ្ងៃ​ស្អែក"
        ],
        "in 1 month": [
            "ខែ​ក្រោយ"
        ],
        "in 1 week": [
            "សប្ដាហ៍​ក្រោយ"
        ],
        "in 1 year": [
            "ឆ្នាំ​ក្រោយ"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) ថ្ងៃ​មុន",
            "(\\d+) ថ្ងៃ​​មុន"
        ],
        "\\1 hour ago": [
            "(\\d+) ម៉ោង​មុន"
        ],
        "\\1 minute ago": [
            "(\\d+) នាទី​មុន",
            "(\\d+) នាទី​​មុន"
        ],
        "\\1 month ago": [
            "(\\d+) ខែមុន"
        ],
        "\\1 second ago": [
            "(\\d+) វិនាទី​មុន"
        ],
        "\\1 week ago": [
            "(\\d+) សប្ដាហ៍​មុន"
        ],
        "\\1 year ago": [
            "(\\d+) ឆ្នាំ​មុន"
        ],
        "in \\1 day": [
            "(\\d+) ថ្ងៃទៀត"
        ],
        "in \\1 hour": [
            "(\\d+) ម៉ោងទៀត",
            "ក្នុង​រយៈ​ពេល (\\d+) ម៉ោង"
        ],
        "in \\1 minute": [
            "(\\d+) នាទីទៀត"
        ],
        "in \\1 month": [
            "(\\d+) ខែទៀត"
        ],
        "in \\1 second": [
            "(\\d+) វិនាទីទៀត"
        ],
        "in \\1 week": [
            "(\\d+) សប្ដាហ៍ទៀត"
        ],
        "in \\1 year": [
            "(\\d+) ឆ្នាំទៀត"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
